@@ -37,6 +37,10 @@ With this package you can:
 
   * Allow for cyclic axes.
 
+  * Read discrete sampling geometry ragged arrays.
+
+  * Read variables that have been compressed by gathering.
+
   * Visualize fields the `cfplot package
     <http://climate.ncas.ac.uk/~andy/cfplot_sphinx/_build/html/>`_.
 
@@ -48,36 +52,22 @@ downloads, installation and source code.
 
 '''
 
-__Conventions__  = 'CF-1.5'
+__Conventions__  = 'CF-1.6'
 __author__       = 'David Hassell'
-__date__         = '2017-06-13'
-__version__      = '1.5.4.post1'
+__date__         = '2017-07-18'
+__version__      = '2.0.1.post2'
 
 from distutils.version import StrictVersion
 import imp
 import platform
 
 # Check the version of python
-if not (StrictVersion('2.6.0')
+if not (StrictVersion('2.7.0')
         <= StrictVersion(platform.python_version())
         < StrictVersion('3.0.0')):
     raise ValueError(
-        "Bad python version: cf requires 2.6 <= python < 3.0. Got %s" %
-        platform.python_version())
-
-## Check the version of numpy
-#import numpy
-#if StrictVersion(numpy.__version__) < StrictVersion('1.7'):
-#    raise ImportError(
-#        "Bad numpy version: cf %s requires numpy >= 1.7. Got %s" %
-#        (__version__, numpy.__version__))
-#
-## Check the version of netCDF4
-#import netCDF4
-#if StrictVersion(netCDF4.__version__) < StrictVersion('0.9.7'):
-#    raise ImportError(
-#        "Bad netCDF4 version: cf %s requires netCDF4 >= 0.9.7. Got %s" %
-#        (__version__, netCDF4.__version__))
+        "Bad python version: cf2 requires 2.7 <= python < 3.0. Got {}".format(
+        platform.python_version()))
 
 try:
     imp.find_module('ESMF')
@@ -87,18 +77,21 @@ else:
     _found_ESMF = True
 
 from .variable             import Variable
+from .boundedvariable      import BoundedVariable, Bounds
 from .coordinate           import Coordinate, DimensionCoordinate, AuxiliaryCoordinate
-from .coordinatebounds     import CoordinateBounds
+#from .coordinatebounds     import CoordinateBounds
 from .coordinatereference  import CoordinateReference
 from .cellmeasure          import CellMeasure
-from .domain               import Domain
+from .domainancillary      import DomainAncillary
+from .domainaxis           import DomainAxis
 from .field                import Field, FieldList
-from .read                 import read
+from .fieldancillary       import FieldAncillary
+from .read                 import read, read1
 from .write                import write
-from .utils                import Dict #List, Dict
+from .utils                import Dict
 from .units                import Units
 from .cfdatetime           import Datetime, dt
-from .timeduration         import TimeDuration, Y, M, D, h, m, s #, fix_reftime_units
+from .timeduration         import TimeDuration, Y, M, D, h, m, s
 from .data.data            import Data
 from .aggregate            import aggregate
 from .query                import (Query, lt, le, gt, ge, eq, ne, contain,
@@ -110,5 +103,25 @@ from .flags                import Flags
 from .cellmethods          import CellMethods
 from .constants            import *
 from .functions            import *
+from .maths                import *
 
 
+'''Version 2 todo list
+
+* [NOT DONE] Check auxiliary mask in Data.concatenate
+* [NOT DONE] Check what's going with the ppps in Field._binary_operation
+* [done] Add to_disk flags to Partition.close parallel
+* [NOT DONE]
+  import numpy, cf2 as cf; f=cf.read('DSG_timeSeriesProfile_indexed_contiguous.nc')[0]
+  print f
+  <snip> 
+  Aux coords     : time(ncdim%station(1), ncdim%element(1)) = [[None]]
+* [NOT DONE] check data.collapse fit in (chunk) memory
+* [NOT DONE] order of axes in um/read.py
+* [NOT DONE] CFA in general - write.py: fits in one chunk?
+* [NOT DONE] test_Regrid is failing and currently turned off
+* [NOT DONE] Consider reinstating my own Datetime which has optional
+  calendar (and becomes one of the others if needs be
+* [NOT DONE] Check cell methods for climatological time collapse
+
+'''
