@@ -2505,3 +2505,98 @@ cf2: 2.0 /home/space/cf-python/cf/__init__.pyc
     else:
         return out
 #--- End: def
+
+def get_relative_vorticity(u, v, cyclic=None, missing_values_at_boundary=False):
+    '''
+
+Calculate the relative vorticity using centred finite
+differences. According to the formula given here:
+
+https://www.ncl.ucar.edu/Document/Functions/Built-in/uv2vr_cfd.shtml
+
+"According to H.B. Bluestein [Synoptic-Dynamic Meteorology in
+Midlatitudes, 1992, Oxford Univ. Press p113-114], let D represent the
+partial derivative, a the radius of the earth, phi the latitude and
+dx2/dy2 the appropriate longitudinal and latitudinal spacing,
+respectively. Then, letting j be the latitude y-subscript, and i be
+the longitude x-subscript:
+
+    rv = Dv/Dx - Du/Dy + (u/a)*tan(phi)
+
+
+    rv(j,i) = (v(j,i+1)-v(j,i-1))/dx2(j)
+              - (u(j+1,i)-u(j-1,i))/dy2(j)
+              + (u(j,i)/a)*tan(phi(j))
+
+The last term accounts for the convergence of the meridians on a
+sphere."
+
+The grid may be global or limited area. If missing values are present
+then missing values will be returned at points where the centred
+finite difference could not be calculated. The boundary conditions may
+be cyclic in longitude. The noncyclic boundaries may either be filled
+with missing values or calculated with off-centre finite differences.
+
+:Parameters:
+
+    u: cf.Field
+        A field containing the x-wind. Must be on the same grid as the
+        y-wind.
+
+    v: cf.Field
+        A field containing the y-wind. Must be on the same grid as the
+        x-wind.
+
+    cyclic: `bool`, optional
+        Whether the longitude is cyclic or not. By default this is
+        autodetected.
+
+    missing_values_at_boundary: `bool`, optional
+        If True then the noncyclic boundaries are filled with missing
+        values. By default it is false and off-centre finite
+        differences are calculated at the boundaries.
+
+:Returns:
+
+    rv: cf.Field
+        The relative vorticity calculated with centred finite
+        differences.
+
+    '''
+
+    # Get the longitude and latitude coordinates
+    u_axis_keys, u_axis_sizes, u_coords = u._regrid_get_latlong('u',
+                                                                return_2D=False)
+    v_axis_keys, v_axis_sizes, v_coords = v._regrid_get_latlong('v',
+                                                                return_2D=False)
+
+    if (not u_coords[0].equals(v_coords[0]) or
+        not u_coords[1].equals(v_coords[1])):
+        raise ValueError('u and v must be on the same grid.')
+    #--- End: if
+
+    # Check for cyclicity
+    if cyclic is None:
+        x_bounds = u_coords[0].get_bounds(create=True)
+        cyclic = abs(x_bounds.datum(-1) - x_bounds.datum(0)) == Data(360,
+                                                                     'degrees')
+    #--- End: if
+
+    # Set boundary conditions
+    if missing_values_at_boundary:
+        x_mode = y_mode = 'constant'
+    else:
+        x_mode = y_mode = 'nearest'
+    #--- End: if
+    if cyclic:
+        x_mode = 'wrap'
+    #--- End: if
+
+    # Copy the longitude and latitude coordinates and convert to radians
+    lon = u_coords[0].copy()
+    lon.units = 'radians'
+    lat = u_coords[1].copy()
+    lat.units = 'radians'
+
+    
+#--- End: def
