@@ -1,4 +1,4 @@
-from glob import glob
+from glob    import glob
 from os      import walk as os_walk
 from os.path import isdir, isfile
 from os.path import join as os_path_join
@@ -15,10 +15,10 @@ from .um.read     import read as um_read
 from .um.read     import is_um_file
 
 def read(files, verbose=False, ignore_read_error=False,
-         aggregate=True, sion=4.5, nfields=None, squeeze=False,
-         unsqueeze=False, fmt=None, select=None, select_options={},
-         top_level=None, height_at_top_of_model=None, recursive=False,
-         follow_symlinks=False, um=None, umversion=None):
+         aggregate=True, nfields=None, squeeze=False, unsqueeze=False,
+         fmt=None, select=None, select_options={}, field=None,
+         height_at_top_of_model=None, recursive=False,
+         follow_symlinks=False, um=None, chunk=True, _debug=False):
     '''Read fields from files into `cf.Field` objects.
 
 A file may be on disk or on a OPeNDAP server.
@@ -49,7 +49,7 @@ Office (UK) fields files format files may be read.
 
 :Parameters:
 
-    files: (arbitrarily nested sequence of) `str`
+    files : (arbitrarily nested sequence of) str
 
         A string or arbitrarily nested sequence of strings giving the
         file names or OPenDAP URLs from which to read fields. Various
@@ -86,23 +86,23 @@ Office (UK) fields files format files may be read.
     verbose: `bool`, optional
         If True then print information to stdout.
     
-    umversion: `int` or `float`, optional
-        Deprecated. Use the *um* instead.
+    umversion:
+        Deprecated. Use the *um* parameter instead.
 
-    ignore_read_error: `bool`, optional
+    ignore_read_error : bool, optional
         If True then ignore any file which raises an IOError whilst
         being read, as would be the case for an empty file, unknown
         file format, etc. By default the IOError is raised.
     
-    fmt: `str`, optional
+    fmt : str, optional
         Only read files of the given format, ignoring all other
         files. Valid formats are ``'NETCDF'`` for CF-netCDF files,
         ``'CFA'`` for CFA-netCDF files and ``'PP'`` for PP files and
-        ``'FF'`` for UM fields files. By default files of any of these
+        'FF' for UM fields files. By default files of any of these
         formats are read.  default files of any of these formats are
         read.
 
-    aggregate: `bool` or `dict`, optional
+    aggregate : bool or dict, optional
         If True (the default) or a (possibly empty) dictionary then
         aggregate the fields read in from all input files into as few
         fields as possible using the CF aggregation rules. If
@@ -110,53 +110,52 @@ Office (UK) fields files format files may be read.
         arguments to the `cf.aggregate` function. If False then the
         fields are not aggregated.
 
-    squeeze: `bool`, optional
+    squeeze : bool, optional
         If True then remove size 1 axes from each field's data array.
 
-    unsqueeze: `bool`, optional
+    unsqueeze : bool, optional
         If True then insert size 1 axes from each field's domain into
         its data array.
 
-    select, select_options: optional
+    select, select_options : *optional*
         Only return fields which satisfy the given conditions on their
         property values. Only fields which, prior to any aggregation,
         satisfy ``f.match(select, **select_options) == True`` are
         returned. See `cf.Field.match` for details.
 
-    top_level: (sequence of) `str`, optional
-        Promote field components to independent top-level fields. The
-        *top_level* parameter may be or, or a sequence, of:
+    field: (sequence of) `str`, optional
+        Create independent fields from field components. The *field*
+        parameter may be one, or a sequence, of:
 
-          ===============  ===========================================
-          *top_level*      Extra top-level fields
-          ===============  ===========================================
-          ``'reference'``  Fields in coordinate reference objects
-          ``'ancillary'``  Ancillary data fields
-          ``'field'``      Fields in coordinate references and
-                           ancillary data fields
-          ``'auxiliary'``  Auxiliary coordinate objects
-          ``'measure'``    Cell measure objects
-          ``'all'``        All of the above
-          ===============  ===========================================
+          ======================  ====================================
+          *field*                 Field components
+          ======================  ====================================
+          ``'field_ancillary'``   Field ancillary objects
+          ``'domain_ancillary'``  Domain ancillary objects
+          ``'dimension'``         Dimension coordinate objects
+          ``'auxiliary'``         Auxiliary coordinate objects
+          ``'measure'``           Cell measure objects
+          ``'all'``               All of the above
+          ======================  ====================================
 
             *Example:*
-              To promote fields in coordinate reference objects:
-              ``top_level='reference'`` or ``top_level=['reference']``.
+              To create fields from auxiliary coordinate objects:
+              ``field='auxiliary'`` or ``field=['auxiliary']``.
 
             *Example:*
-              To promote ancillary data fields and cell measure
-              objects: ``top_level=['ancillary', 'measure']``.
+              To create fields from domain ancillary and cell measure
+              objects: ``field=['domain_ancillary', 'measure']``.
 
         .. versionadded:: 1.0.4
 
-    recursive: `bool`, optional
+    recursive : bool, optional
         If True then allow directories to be specified by the *files*
         parameter and recursively search the directories for files to
         read.
 
         .. versionadded:: 1.1.9
 
-    follow_symlinks: `bool`, optional
+    follow_symlinks : bool, optional
         If True, and *recursive* is True, then also search for files
         in directories which resolve to symbolic links. By default
         directories which resolve to symbolic links are
@@ -203,21 +202,22 @@ Office (UK) fields files format files may be read.
         If format is specified as PP then the word size and byte order
         default to ``4`` and ``'big'`` repsectively.
 
-            *Example:*
-              To specify that the input files are 32-bit, big-endian
-              PP files: ``um={'fmt': 'PP'}``
+          *Example:*
+            To specify that the input files are 32-bit, big-endian
+            PP files: ``um={'fmt': 'PP'}``
 
-            *Example:*
-              To specify that the input files are 32-bit,
-              little-endian PP files from version 5.1 of the Unified
-              Model: ``um={'fmt': 'PP', 'endian': 'little', 'version':
-              5.1}``
+          *Example:*
+            To specify that the input files are 32-bit,
+            little-endian PP files from version 5.1 of the Unified
+            Model: ``um={'fmt': 'PP', 'endian': 'little', 'version':
+            5.1}``
 
         .. versionadded:: 1.5
 
+
 :Returns:
     
-    out: `cf.FieldList` or `cf.Field`
+    out : cf.FieldList or cf.Field
         A list of fields, or if there is only one field, the
         individual field.
 
@@ -272,20 +272,11 @@ Office (UK) fields files format files may be read.
 
     aggregate_options['copy'] = False
     
-    # ----------------------------------------------------------------
-    # Parse top_level
-    # ----------------------------------------------------------------
-    promote = top_level
-    if promote is None:
-        promote = ()
-    elif isinstance(promote, basestring):
-        promote = (promote,)
-
-#    if 'all' in promote:
-#        promote = set(('field', 'coordinate', 'measure'))
-        
-    if umversion is not None:
-        raise ValueError("The umversion parameter has been deprecated. Use the um parameter instead")    
+    # Parse the field parameter
+    if field is None:
+        field = ()
+    elif isinstance(field, basestring):
+        field = (field,)
 
     # Count the number of fields (in all files) and the number of
     # files
@@ -303,7 +294,7 @@ Office (UK) fields files format files may be read.
         else:
             # Glob files on disk
             files2 = glob(file_glob)
-
+            
             if not files2 and not ignore_read_error:
                 open(file_glob, 'rb')
                 
@@ -312,7 +303,7 @@ Office (UK) fields files format files may be read.
                 for x in files2:
                     if isdir(x):
                         # Recursively walk through directories
-                        for path, subdirs, filenames in os_walk(x, followlinks=follow_symlinks):
+                        for path, subdirs, filenames in os_walk(x, followlinks=True):
                             files3.extend(os_path_join(path, f) for f in filenames)
                     else:
                         files3.append(x)
@@ -326,8 +317,8 @@ Office (UK) fields files format files may be read.
 
         for filename in files2:
             if verbose:
-                print 'File: %s' % filename
-
+                print 'File: {0}'.format(filename)
+                
             # --------------------------------------------------------
             # Read the file into fields
             # --------------------------------------------------------
@@ -338,8 +329,10 @@ Office (UK) fields files format files may be read.
                                   aggregate_options=aggregate_options,
                                   selected_fmt=fmt,
                                   um=um,
-                                  promote=promote,
-                                  height_at_top_of_model=height_at_top_of_model)
+                                  field=field,
+                                  height_at_top_of_model=height_at_top_of_model,
+                                  chunk=chunk,
+                                  _debug=_debug)
             
             # --------------------------------------------------------
             # Select matching fields
@@ -372,7 +365,7 @@ Office (UK) fields files format files may be read.
             field_counter, _plural(field_counter),
             file_counter , _plural(file_counter)))
     #--- End: if
-    
+   
     # ----------------------------------------------------------------
     # Aggregate the output fields
     # ----------------------------------------------------------------
@@ -411,25 +404,32 @@ Office (UK) fields files format files may be read.
     # 3) Nothing
     # ----------------------------------------------------------------
     if squeeze:
-        field_list.squeeze(i=True)
+        [f.squeeze(i=True) for f in field_list]
     elif unsqueeze:
-        field_list.unsqueeze(i=True)
+        [f.unsqueeze(i=True) for f in field_list]
 
     if nfields is not None and len(field_list) != nfields:
         raise ValueError(
-            "Error whilst reading file{0}: {1} field{2} requested but {3} found".format(
-                _plural(file_counter),
-                nfields,
-                _plural(nfields),
-                len(field_list)))
+            "Error whilst reading file{}: {} field{} requested but {} fields found".format(
+    _plural(file_counter), nfields, _plural(nfields), len(field_list)))
 
-    if len(field_list) == 1:
-        # Return a field instead of a field list
-        field_list = field_list[0]
+#    if len(field_list) == 1:
+#        # Return a field instead of a field list
+#        field_list = field_list[0]
 
     return field_list
 #--- End: def
 
+def read1(*args, **kwargs):
+    '''``f=cf.read1(*args, **kwargs)`` is equivalent to ``f=cf.read(*args,
+nfields=1, **kwargs)[0]``
+
+    '''
+    kwargs['nfields'] = 1
+    return read(*args, **kwargs)[0]
+#--- End: def
+
+
 def _plural(n):
     return 's' if n !=1 else ''
 
@@ -440,8 +440,10 @@ def _read_a_file(filename,
                  verbose=False,
                  selected_fmt=None,
                  um=None,
-                 promote=(),
-                 height_at_top_of_model=None):
+                 field=(),
+                 height_at_top_of_model=None,
+                 chunk=True,
+                 _debug=False):
     '''
 
 Read the contents of a single file into a field list.
@@ -484,7 +486,7 @@ Read the contents of a single file into a field list.
     word_size = None
     endian    = None
     umversion = 405
-
+    
     if um:
         ftype = 'UM' 
         fmt       = um.get('fmt')
@@ -499,6 +501,7 @@ Read the contents of a single file into a field list.
                 word_size = 4
             if endian is None:
                 endian = 'big'
+        #--- End: if
         if umversion is not None:
             umversion = float(str(umversion).replace('.', '0', 1))
     else:
@@ -511,19 +514,21 @@ Read the contents of a single file into a field list.
                 return FieldList()
             raise Exception(error)
     #--- End: if
-
+    
     # ----------------------------------------------------------------
     # Still here? Read the file into fields.
     # ----------------------------------------------------------------
     if ftype == 'netCDF' and (selected_fmt in (None, 'NETCDF', 'CFA')):
-        fields = netcdf_read(filename, fmt=selected_fmt, promote=promote,
-                             verbose=verbose)
+        fields = netcdf_read(filename, fmt=selected_fmt, field=field,
+                             verbose=verbose, chunk=chunk,
+                             _debug=_debug)
         
     elif ftype == 'UM' and (selected_fmt in (None, 'PP', 'FF')):
         fields = um_read(filename, um_version=umversion,
                          verbose=verbose, set_standard_name=True,
                          height_at_top_of_model=height_at_top_of_model,
-                         fmt=fmt, word_size=word_size, endian=endian)
+                         fmt=fmt, word_size=word_size, endian=endian,
+                         chunk=chunk)
 
         # PP fields are aggregated intrafile prior to interfile
         # aggregation
@@ -549,17 +554,17 @@ def file_type(filename):
 
 :Parameters:
 
-    filename: `str`
+    filename : str
         The file name.
 
 :Returns:
 
-    out: `str`
+    out : str
         The format type of the file.
 
 :Raises:
  
-    IOError:
+    IOError :
         If the file has an unsupported format.
 
 :Examples:
