@@ -38,21 +38,22 @@ and auxiliary coordinate roles for different data variables.
           Expansion             Description
           ====================  ======================================
           Tilde                 An initial component of ``~`` or
-                                ``~user`` is replaced by that *user*'s
+                                ``~user`` is replaced by that user's
                                 home directory.
            
           Environment variable  Substrings of the form ``$name`` or
                                 ``${name}`` are replaced by the value
-                                of environment variable *name*.
+                                of environment variable ``name``.
           ====================  ======================================
     
         Where more than one type of expansion is used in the same
         string, they are applied in the order given in the above
         table.
 
-          Example: If the environment variable *MYSELF* has been set
-          to the "david", then ``'~$MYSELF/out.nc'`` is equivalent to
-          ``'~david/out.nc'``.
+          *Example:*
+            If the environment variable ``MYSELF`` has been set to the
+            ``'david'``, then ``'~$MYSELF/out.nc'`` is equivalent to
+            ``'~david/out.nc'``.
   
     fmt: `str`, optional
         The format of the output file. One of:
@@ -76,7 +77,7 @@ and auxiliary coordinate roles for different data variables.
         pre-exists. By default a pre-existing output file is over
         written.
 
-    verbose: `bool`, optional
+    verbose : `bool`, optional
         If True then print one-line summaries of each field written.
 
     cfa_options: `dict`, optional
@@ -136,12 +137,12 @@ and auxiliary coordinate roles for different data variables.
         precision of 0.01. In conjunction with the *compress*
         parameter this produces 'lossy', but significantly more
         efficient compression.
-
+    
     fletcher32: `bool`, optional
         If True then the Fletcher-32 HDF5 checksum algorithm is
         activated to detect compression errors. Ignored if *compress*
         is ``0``.
-
+ 
     no_shuffle: `bool`, optional
         If True then the HDF5 shuffle filter (which de-interlaces a
         block of data before compression by reordering the bytes by
@@ -160,13 +161,13 @@ and auxiliary coordinate roles for different data variables.
         dictionary whose are input data types with values of output
         data types.
 
-          **Example:**
+          *Example:*
             To convert 64-bit floats and 64-bit integers to their
             32-bit counterparts: ``datatype={numpy.dtype('float64'):
             numpy.dtype('float32'), numpy.dtype('int64'):
             numpy.dtype('int32')}``.
        
-    single: `bool`, optional
+   single: `bool`, optional
         Write 64-bit floats as 32-bit floats and 64-bit integers as
         32-bit integers. By default, input data types are
         preserved. Note that ``single=True`` is exactly equivalent to
@@ -179,7 +180,7 @@ and auxiliary coordinate roles for different data variables.
         preserved. Note that ``double=True`` is exactly equivalent to
         ``datatype={numpy.dtype('float32'): numpy.dtype('float64'),
         numpy.dtype('int32'): numpy.dtype('int64')}``.
- 
+
     HDF_chunksizes: `dict`, optional
         Manually specify HDF5 chunks for the field data arrays.
 
@@ -217,24 +218,23 @@ and auxiliary coordinate roles for different data variables.
         users will read from the file.
 
     unlimited: sequence of `str`, optional
-
         Create a unlimited dimensions (dimensions that can be appended
         to). A dimension is identified by either a standard name; one
-        of T, Z, Y, X denoting time, height or horixontal axes (as
-        defined by the CF conventions); or the value of an arbitrary
-        CF property preceeded by the property name and a colon. For
-        example:
+        of T, Z, Y, X denoting time, height or horixontal axes
+        repsectively (as defined by the CF conventions); or the value
+        of an arbitrary CF property preceeded by the property name and
+        a colon. For example:
 
          Multiple unlimited axes may be defined by specifying more
          than one --unlimited option. Note, however, that only netCDF4
          formats support multiple unlimited dimensions. For example,
          to set the time and Z dimensions to be unlimited you could
-         use --unlim- ited=time --unlimited=Z
-
+         use unlim- ited=time --unlimited=Z
+ALERT
               An example of defining an axis by an arbitrary CF property could
               be --unlimited=long_name:pseudo_level
+ALERT
 
-       
 :Returns:
 
     `None`
@@ -251,18 +251,12 @@ and auxiliary coordinate roles for different data variables.
  <CF Field: u_compnt_of_wind(19, 29, 24)>,
  <CF Field: v_compnt_of_wind(19, 29, 24)>,
  <CF Field: potential_temperature(19, 30, 24)>]
->>> write(f
-
-    , 'file')
+>>> write(f, 'file')
 
 >>> type(f)
-<clas
-
-    s 'cf.field.FieldList'>
+<class 'cf.field.FieldList'>
 >>> type(g)
-<clas
-
-    s 'cf.field.Field'>
+<class 'cf.field.Field'>
 >>> cf.write([f, g], 'file.nc', verbose=True)
 [<CF Field: air_pressure(30, 24)>,
  <CF Field: u_compnt_of_wind(19, 29, 24)>,
