@@ -1,3 +1,4 @@
+import datetime
 import os
 import itertools
 import time
@@ -31,6 +32,7 @@ class DataTest(unittest.TestCase):
     
     test_only = []
 #    test_only = ['NOTHING!!!!!']
+#    test_only = ['test_Data_AUXILIARY_MASK']
 #    test_only = ['test_Data__asdatetime__asreftime__isdatetime']
 #    test_only = ['test_Data__collapse_UNWEIGHTED_MASKED']
 #    test_only = ['test_Data__collapse_UNWEIGHTED_UNMASKED']
@@ -863,7 +865,7 @@ class DataTest(unittest.TestCase):
 
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
-        
+
     def test_Data_BROADCASTING(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -1401,7 +1403,7 @@ class DataTest(unittest.TestCase):
 
 
 if __name__ == "__main__":
-    print 'cf-python version:'     , cf.__version__
-    print 'cf-python path:'        , os.path.abspath(cf.__file__)
-    print ''
+    print 'Run date:', datetime.datetime.now()
+    cf.environment()
+    print''
     unittest.main(verbosity=2)
