@@ -19,7 +19,7 @@ class FieldTest(unittest.TestCase):
 
         self.test_only = []
 #        self.test_only = ['test_Field___add__']
-        self.test_only = ['test_Field_collapse']
+#        self.test_only = ['test_Field_collapse']
 #        self.test_only = ['test_Field_transpose','test_Field_squeeze']
 #        self.test_only = ['test_Field_match','test_Field_items']
 #        self.test_only = ['test_Field_items']
@@ -35,7 +35,8 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        for chunksize in self.chunk_sizes:            
+        for chunksize in self.chunk_sizes:
+            cf.CHUNKSIZE(chunksize)
             f = cf.read1(self.filename).squeeze()
 
             f[...] = 0
@@ -58,7 +59,8 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        for chunksize in self.chunk_sizes:            
+        for chunksize in self.chunk_sizes:
+            cf.CHUNKSIZE(chunksize)
             f = cf.read1(self.filename).squeeze()
             g = f.copy()
             f_plus_g = f + g
@@ -83,7 +85,8 @@ class FieldTest(unittest.TestCase):
 
         dimarray = self.f.dim('grid_lon').array
       
-        for chunksize in self.chunk_sizes:            
+        for chunksize in self.chunk_sizes:
+            cf.CHUNKSIZE(chunksize)
             f = cf.read1(self.filename)
 
             for period in (dimarray.min()-5, dimarray.min()):
@@ -164,7 +167,8 @@ class FieldTest(unittest.TestCase):
 #        if self.test_only and inspect.stack()[0][3] not in self.test_only:
 #            return
 #
-#        for chunksize in self.chunk_sizes:            
+#        for chunksize in self.chunk_sizes:
+#            cf.CHUNKSIZE(chunksize)
 #            f = cf.read(self.filename)[0]
 #            
 #            
@@ -344,17 +348,14 @@ class FieldTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        f0 = cf.read(self.filename)
+        f = cf.read1(self.filename)
 
-        for f in (f0[0], f0):
-            f = f.copy()
-            f.squeeze(i=True)
-            g = f.copy()
-            h = f.copy()
-            i = h.squeeze(i=True)
-            self.assertTrue(f.equals(g))
-            self.assertTrue(h is i)
-        #--- End: for    
+        f.squeeze(i=True)
+        g = f.copy()
+        h = f.copy()
+        i = h.squeeze(i=True)
+        self.assertTrue(f.equals(g))
+        self.assertTrue(h is i)
     #--- End: def
 
     def test_Field_transpose(self):
@@ -387,6 +388,7 @@ class FieldTest(unittest.TestCase):
             return
 
         for chunksize in self.chunk_sizes:
+            cf.CHUNKSIZE(chunksize)
             f = cf.read(self.filename2)[0]
 
             g = f.collapse('mean')
@@ -451,6 +453,7 @@ class FieldTest(unittest.TestCase):
         a = f.array
 
         for chunksize in self.chunk_sizes:
+            cf.CHUNKSIZE(chunksize)
             f = cf.read(self.filename)[0]
 
             for condition in (True, 1, [[[True]]], [[[[[456]]]]]):
@@ -479,11 +482,10 @@ class FieldTest(unittest.TestCase):
             return
 
         f = cf.read(self.filename)[0]
-
         g = f.mask_invalid()
-        g = cf.FieldList(f).mask_invalid()
-        g = f.mask_invalid(i=True)
-        g = cf.FieldList(f).mask_invalid(i=True)
+
+        f = cf.read(self.filename)[0]
+        f.mask_invalid(i=True)
     #--- End: def
         
 #--- End: class
